==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property header Indicates if the CSV data has a header.
 */
public data class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs(
    public val `header`: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs =
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs.builder()
            .`header`(`header`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs].
 */
@PulumiTagMarker
public class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgsBuilder
internal constructor() {
    private var `header`: Output<Boolean>? = null

    /**
     * @param value Indicates if the CSV data has a header.
     */
    @JvmName("mqnwqcmbtuwypyio")
    public suspend fun `header`(`value`: Output<Boolean>) {
        this.`header` = value
    }

    /**
     * @param value Indicates if the CSV data has a header.
     */
    @JvmName("mcujxmrupduwrrbk")
    public suspend fun `header`(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    internal fun build():
        DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs =
        DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs(
            `header` = `header`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property header Indicates if the CSV data has a header.
 */
public data class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs(
    public val `header`: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs =
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs.builder()
            .`header`(`header`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs].
 */
@PulumiTagMarker
public class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgsBuilder
internal constructor() {
    private var `header`: Output<Boolean>? = null

    /**
     * @param value Indicates if the CSV data has a header.
     */
    @JvmName("nttsoigqnfxbsmfo")
    public suspend fun `header`(`value`: Output<Boolean>) {
        this.`header` = value
    }

    /**
     * @param value Indicates if the CSV data has a header.
     */
    @JvmName("mwheffamiksaruju")
    public suspend fun `header`(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`header` = mapped
    }

    internal fun build(): DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs =
        DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsvArgs(
            `header` = `header`,
        )
}
